import { Grid, TextField, Typography } from "@mui/material";
import React, { memo, useState, useEffect, useMemo} from "react";


const TaskDefault = ({task, onClickTaskHandler}) => {
  return(<Grid  
        sx={{backgroundColor: 'lightgreen', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', borderRadius: '10px', margin:"5px 10px"}} 
        onClick={onClickTaskHandler}
        >
          <span>
            {task.title}
          </span>
    </Grid>)
}

const TaskWithNoStartAndAllEnd = ({task, onClickTaskHandler}) => {
  return(<Grid
        sx={{backgroundColor: 'lightgreen', whiteSpace: 'nowrap', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', borderTopLeftRadius: '10px', borderBottomLeftRadius: '10px', margin:"5px -1px 5px 10px", position:'relative'}} 
        onClick={onClickTaskHandler}
        >
          <span>
            {task.title}
          </span>
    </Grid>)
}
const TaskWithAllStartAndNoEnd = ({task, onClickTaskHandler}) => {
  return(<Grid  
        sx={{backgroundColor: 'lightgreen', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', borderTopRightRadius: '10px', borderBottomRightRadius: '10px', margin:"5px 10px 5px -1px"}} 
        onClick={onClickTaskHandler}
        >
          <span>
            	&#8291;
          </span>
    </Grid>)
}
const TaskWithAllStartAndAllEnd = ({task, onClickTaskHandler}) => {
  return(<Grid  
        sx={{backgroundColor: 'lightgreen', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', margin:"5px -1px"}} 
        onClick={onClickTaskHandler}
        >
          <span>
            	&#8291;
          </span>
    </Grid>)
}




const CalendarTask = ({year, month, tasks, day, hours, setCurrentTask, hourFormat, handleOpen, currentTask}) => {

  const [thisCellCurrentTask, setThisCellCurrentTask] = useState({})

  const hour = parseInt(hours.split(':')[0])
  const tasksCell = useMemo(() => {
    let hourDiffEnd
    if (hourFormat) {
      hourDiffEnd = hour + 1
    } else {
      hourDiffEnd = hour + 2
    }
    const tasksCell = tasks.filter(task=> {
    if (year === task.infoForCell.startYear) {
      if (month + 1 === task.infoForCell.startMonth) {
        if (day.dayNumber === task.infoForCell.startDay) {
          if (((task.infoForCell.endHour <= hour || task.infoForCell.startHour <= hour) && (task.infoForCell.endHour > hour))  
          || (task.infoForCell.startHour >= hour  && task.infoForCell.endHour < hourDiffEnd)
          || (task.infoForCell.endMinute <= 59 && task.infoForCell.endHour === hour)) {
              return task
          }
        }
      }      
    }
    })
    tasksCell.sort(function(a,b){
      const durattionFirstDate = new Date(a.dateTimeDue).getTime() - new Date(a.dateTimeStart).getTime()
      const durattionSecondDate = new Date(b.dateTimeDue).getTime() - new Date(b.dateTimeStart).getTime()
      return durattionSecondDate - durattionFirstDate;
    });
    return tasksCell
  }, [hourFormat, month, tasks])

  useEffect(()=>{
    if (!currentTask.title) {
      setThisCellCurrentTask({})
    }
  }, [currentTask])

  const onClickTaskHandler = (e, task) => {
    e.stopPropagation(); 
    setCurrentTask(task); 
    handleOpen(e)
  }


  return (<> 
      {tasksCell.length ? tasksCell.map((task, i)=>
      {

        if (hourFormat && task.infoForCell.endHour > hour && task.infoForCell.startHour === hour || (!hourFormat && task.infoForCell.endHour > hour + 1 && (task.infoForCell.startHour === hour))) {
          return (
            <TaskWithNoStartAndAllEnd
              key={task.id}
              task={task}
              onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
            />
          )
        }
        if (hourFormat && task.infoForCell.startHour < hour && task.infoForCell.endHour > hour || ((!hourFormat && task.infoForCell.startHour  < hour && task.infoForCell.endHour  > hour + 2))) {
          return (
            <TaskWithAllStartAndAllEnd
              key={task.id}
              task={task}
              onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
            />
          )
        }
        if (hourFormat && task.infoForCell.endMinute === 59 && task.infoForCell.startHour < hour || (!hourFormat && task.infoForCell.endMinute === 59 && task.infoForCell.startHour < hour && (task.infoForCell.endHour === hour || task.infoForCell.endHour === hour + 1 && task.infoForCell.startHour + 1 !== hour))) {
          return (<>
            <TaskWithAllStartAndNoEnd
              key={task.id}
              task={task}
              onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
            />
          </>)
        }
        return (<>
          <TaskDefault
            key={task.id}
            task={task}
            onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
          />
        </>)}
      ) 
      : null}
  </>)
};

export default memo(CalendarTask);